==> rfPermute_2.1.5.tar.gz: rfPermute/R/pctCorrect.R <==
#' @title Percent Correctly Classified
#' @description Calculate the percent of individuals correctly classified in 
#'   a specified percent of trees in the forest.
#' 
#' @param rf a \code{\link[randomForest]{randomForest}} or \code{rfPermute} object.
#' @param pct vector of minimum percent of trees voting for each class. Can be 
#'   \code{0:1} or \code{0:100}.
#' 
#' @return a matrix giving the percent of individuals correctly classified in 
#'   each class and overall for each threshold value specified in \code{pct}.
#' 
#' @author Eric Archer \email{eric.archer@@noaa.gov} 
#' 
#' @examples
#' data(mtcars)
#'
#' rf <- randomForest(factor(am) ~ ., mtcars, importance = TRUE)
#' pctCorrect(rf)
#' 
#' @importFrom swfscMisc isBetween
#' @export
#' 
pctCorrect <- function(rf, pct = c(seq(0.8, 0.95, 0.05), 0.99)) {
  if(!inherits(rf, "randomForest")) {
    stop("'rf' must be a randomForest object or inherit from one")
  }
  pct.good <- FALSE
  if(is.numeric(pct)) {
    zero.one <- all(isBetween(pct, 0, 1, include.ends = TRUE))
    if(zero.one) pct.good <- TRUE
    zero.hundred <- all(isBetween(pct, 0, 100, include.ends = TRUE))
    if(zero.hundred & !zero.one) {
      pct <- pct / 100
      pct.good <- TRUE
    }
  }
  if(!pct.good) stop("'pct' must be a numeric vector with values in the range of 0:1 or 0:100")
  
  mat <- do.call(cbind, lapply(pct, function(p) {
    is.correct <- sapply(names(rf$y), function(id) {
      rf$votes[id, rf$y[id]] >= p
    })
    by.strata <- tapply(is.correct, rf$y, mean)
    c(by.strata, Overall = mean(is.correct))
  }))
  colnames(mat) <- paste("pct.correct_", pct, sep = "")
  mat * 100
}

==> rfPermute_2.2.tar.gz: rfPermute/R/pctCorrect.R <==
#' @title Percent Correctly Classified
#' @description Calculate the percent of individuals correctly classified in 
#'   a specified percent of trees in the forest.
#' 
#' @param rf a \code{\link[randomForest]{randomForest}} or \code{rfPermute} object.
#' @param pct vector of minimum percent of trees voting for each class. Can be 
#'   \code{0:1} or \code{0:100}.
#' 
#' @return a matrix giving the percent of individuals correctly classified in 
#'   each class and overall for each threshold value specified in \code{pct}.
#' 
#' @author Eric Archer \email{eric.archer@@noaa.gov} 
#' 
#' @examples
#' data(mtcars)
#'
#' rf <- randomForest(factor(am) ~ ., mtcars, importance = TRUE)
#' pctCorrect(rf)
#' 
#' @export
#' 
pctCorrect <- function(rf, pct = c(seq(0.8, 0.95, 0.05), 0.99)) {
  if(!inherits(rf, "randomForest")) {
    stop("'rf' must be a randomForest object or inherit from one")
  }
  pct.good <- FALSE
  if(is.numeric(pct)) {
    zero.one <- all(swfscMisc::isBetween(pct, 0, 1, include.ends = TRUE))
    if(zero.one) pct.good <- TRUE
    zero.hundred <- all(swfscMisc::isBetween(pct, 0, 100, include.ends = TRUE))
    if(zero.hundred & !zero.one) {
      pct <- pct / 100
      pct.good <- TRUE
    }
  }
  if(!pct.good) {
    stop("'pct' must be a numeric vector with values in the range of 0:1 or 0:100")
  }
  
  mat <- do.call(cbind, lapply(pct, function(p) {
    is.correct <- sapply(names(rf$y), function(id) {
      rf$votes[id, rf$y[id]] >= p & rf$y[id] == rf$predicted[id]
    })
    by.class <- tapply(is.correct, rf$y, mean)
    c(by.class, Overall = mean(is.correct))
  }))
  colnames(mat) <- paste("pct.correct_", pct, sep = "")
  mat <- cbind(data.frame(class = rownames(mat)), mat * 100)
  rownames(mat) <- NULL
  mat
}
